summaryrefslogtreecommitdiff
path: root/connectivity/inc
diff options
context:
space:
mode:
Diffstat (limited to 'connectivity/inc')
-rw-r--r--connectivity/inc/connectivity/CommonTools.hxx4
-rw-r--r--connectivity/inc/connectivity/DateConversion.hxx20
-rw-r--r--connectivity/inc/connectivity/PColumn.hxx18
-rw-r--r--connectivity/inc/connectivity/SQLStatementHelper.hxx3
-rw-r--r--connectivity/inc/connectivity/dbconversion.hxx9
-rw-r--r--connectivity/inc/connectivity/dbtools.hxx2
-rw-r--r--connectivity/inc/connectivity/filtermanager.hxx7
-rw-r--r--connectivity/inc/connectivity/sqlerror.hxx8
-rw-r--r--connectivity/inc/connectivity/sqliterator.hxx38
-rw-r--r--connectivity/inc/connectivity/sqlnode.hxx51
-rw-r--r--connectivity/inc/connectivity/sqlparse.hxx15
-rw-r--r--connectivity/inc/connectivity/virtualdbtools.hxx7
-rwxr-xr-x[-rw-r--r--]connectivity/inc/makefile.mk0
13 files changed, 94 insertions, 88 deletions
diff --git a/connectivity/inc/connectivity/CommonTools.hxx b/connectivity/inc/connectivity/CommonTools.hxx
index c17b4f37ce..494db79b06 100644
--- a/connectivity/inc/connectivity/CommonTools.hxx
+++ b/connectivity/inc/connectivity/CommonTools.hxx
@@ -54,6 +54,10 @@ namespace connectivity
{
//------------------------------------------------------------------------------
OOO_DLLPUBLIC_DBTOOLS sal_Bool match(const sal_Unicode* pWild, const sal_Unicode* pStr, const sal_Unicode cEscape);
+ inline sal_Bool match(const ::rtl::OUString &rWild, const ::rtl::OUString &rStr, const sal_Unicode cEscape)
+ {
+ return match(rWild.getStr(), rStr.getStr(), cEscape);
+ }
//------------------------------------------------------------------------------
OOO_DLLPUBLIC_DBTOOLS rtl::OUString toString(const ::com::sun::star::uno::Any& rValue);
OOO_DLLPUBLIC_DBTOOLS rtl::OUString toDateString(const ::com::sun::star::util::Date& rDate);
diff --git a/connectivity/inc/connectivity/DateConversion.hxx b/connectivity/inc/connectivity/DateConversion.hxx
index caa05b1e74..da7ec816be 100644
--- a/connectivity/inc/connectivity/DateConversion.hxx
+++ b/connectivity/inc/connectivity/DateConversion.hxx
@@ -41,52 +41,52 @@ namespace connectivity
public:
static sal_Int32 toINT32(const ::com::sun::star::util::Date&)
{
- OSL_ENSURE(0,"Please use DBConversion instead!");
+ OSL_FAIL("Please use DBConversion instead!");
return 0;
}
static sal_Int32 toINT32(const ::com::sun::star::util::Time&)
{
- OSL_ENSURE(0,"Please use DBConversion instead!");
+ OSL_FAIL("Please use DBConversion instead!");
return 0;
}
static sal_Int64 toINT64(const ::com::sun::star::util::DateTime&)
{
- OSL_ENSURE(0,"Please use DBConversion instead!");
+ OSL_FAIL("Please use DBConversion instead!");
return 0;
}
static sal_Int32 getMsFromTime(const ::com::sun::star::util::Time&)
{
- OSL_ENSURE(0,"Please use DBConversion instead!");
+ OSL_FAIL("Please use DBConversion instead!");
return 0;
}
static double toDouble(const ::com::sun::star::util::Date&)
{
- OSL_ENSURE(0,"Please use DBConversion instead!");
+ OSL_FAIL("Please use DBConversion instead!");
return 0;
}
static double toDouble(const ::com::sun::star::util::Time&)
{
- OSL_ENSURE(0,"Please use DBConversion instead!");
+ OSL_FAIL("Please use DBConversion instead!");
return 0;
}
static double toDouble(const ::com::sun::star::util::DateTime&)
{
- OSL_ENSURE(0,"Please use DBConversion instead!");
+ OSL_FAIL("Please use DBConversion instead!");
return 0;
}
static ::com::sun::star::util::Date toDate(double,const ::com::sun::star::util::Date& =::com::sun::star::util::Date(01,01,1900))
{
- OSL_ENSURE(0,"Please use DBConversion instead!");
+ OSL_FAIL("Please use DBConversion instead!");
return ::com::sun::star::util::Date();
}
static ::com::sun::star::util::Time toTime(double)
{
- OSL_ENSURE(0,"Please use DBConversion instead!");
+ OSL_FAIL("Please use DBConversion instead!");
return ::com::sun::star::util::Time();
}
static ::com::sun::star::util::DateTime toDateTime(double,const ::com::sun::star::util::Date& =::com::sun::star::util::Date(01,01,1900))
{
- OSL_ENSURE(0,"Please use DBConversion instead!");
+ OSL_FAIL("Please use DBConversion instead!");
return ::com::sun::star::util::DateTime();
}
};
diff --git a/connectivity/inc/connectivity/PColumn.hxx b/connectivity/inc/connectivity/PColumn.hxx
index f929085a5e..16e013237d 100644
--- a/connectivity/inc/connectivity/PColumn.hxx
+++ b/connectivity/inc/connectivity/PColumn.hxx
@@ -126,15 +126,27 @@ namespace connectivity
class OOO_DLLPUBLIC_DBTOOLS OOrderColumn :
public OOrderColumn_BASE, public OOrderColumn_PROP
{
- sal_Bool m_bAscending;
- sal_Bool m_bOrder;
+ const sal_Bool m_bAscending;
+ const ::rtl::OUString m_sTableName;
+
protected:
virtual ::cppu::IPropertyArrayHelper* createArrayHelper() const;
virtual ::cppu::IPropertyArrayHelper & SAL_CALL getInfoHelper();
virtual ~OOrderColumn();
public:
- OOrderColumn(const ::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet>& _xColumn,sal_Bool _bCase,sal_Bool _bAscending);
+ OOrderColumn(
+ const ::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet>& _xColumn,
+ const ::rtl::OUString& i_rOriginatingTableName,
+ sal_Bool _bCase,
+ sal_Bool _bAscending
+ );
+
+ OOrderColumn(
+ const ::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet>& _xColumn,
+ sal_Bool _bCase,
+ sal_Bool _bAscending
+ );
virtual void construct();
diff --git a/connectivity/inc/connectivity/SQLStatementHelper.hxx b/connectivity/inc/connectivity/SQLStatementHelper.hxx
index 4cad600437..14d3dcf5f4 100644
--- a/connectivity/inc/connectivity/SQLStatementHelper.hxx
+++ b/connectivity/inc/connectivity/SQLStatementHelper.hxx
@@ -7,9 +7,6 @@
*
* OpenOffice.org - a multi-platform office productivity suite
*
- * $RCSfile: dbtools.hxx,v $
- * $Revision: 1.37 $
- *
* This file is part of OpenOffice.org.
*
* OpenOffice.org is free software: you can redistribute it and/or modify
diff --git a/connectivity/inc/connectivity/dbconversion.hxx b/connectivity/inc/connectivity/dbconversion.hxx
index 851a65fe8a..e52294ba02 100644
--- a/connectivity/inc/connectivity/dbconversion.hxx
+++ b/connectivity/inc/connectivity/dbconversion.hxx
@@ -99,17 +99,18 @@ namespace dbtools
const double& rValue,
sal_Int16 nKeyType) throw(::com::sun::star::lang::IllegalArgumentException);
- static double getValue(const ::com::sun::star::uno::Reference< ::com::sun::star::sdb::XColumn>& xVariant, const ::com::sun::star::util::Date& rNullDate,
- sal_Int16 nKeyType);
+ static double getValue( const ::com::sun::star::uno::Reference< ::com::sun::star::sdb::XColumn>& xVariant, const ::com::sun::star::util::Date& rNullDate );
// get the columnvalue as string with a default format given by the column or a default format
// for the type
- static ::rtl::OUString getValue(const ::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet>& _xColumn,
+ static ::rtl::OUString getFormattedValue(
+ const ::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet>& _xColumn,
const ::com::sun::star::uno::Reference< ::com::sun::star::util::XNumberFormatter>& xFormatter,
const ::com::sun::star::lang::Locale& _rLocale,
const ::com::sun::star::util::Date& rNullDate);
- static ::rtl::OUString getValue(const ::com::sun::star::uno::Reference< ::com::sun::star::sdb::XColumn>& _xColumn,
+ static ::rtl::OUString getFormattedValue(
+ const ::com::sun::star::uno::Reference< ::com::sun::star::sdb::XColumn>& _xColumn,
const ::com::sun::star::uno::Reference< ::com::sun::star::util::XNumberFormatter>& xFormatter,
const ::com::sun::star::util::Date& rNullDate,
sal_Int32 nKey,
diff --git a/connectivity/inc/connectivity/dbtools.hxx b/connectivity/inc/connectivity/dbtools.hxx
index ddab63ea76..a22e489724 100644
--- a/connectivity/inc/connectivity/dbtools.hxx
+++ b/connectivity/inc/connectivity/dbtools.hxx
@@ -613,7 +613,7 @@ namespace dbtools
const ::com::sun::star::uno::Reference< ::com::sun::star::sdbc::XParameters>& _xParameters,
const ::com::sun::star::uno::Reference< ::com::sun::star::sdbc::XConnection>& _xConnection,
const ::com::sun::star::uno::Reference< ::com::sun::star::task::XInteractionHandler >& _rxHandler,
- const ::std::bit_vector& _aParametersSet = ::std::bit_vector());
+ const ::std::vector<bool, std::allocator<bool> >& _aParametersSet = ::std::vector<bool, std::allocator<bool> >());
/** call the appropiate set method for the specific sql type @see com::sun::star::sdbc::DataType
@param _xParams the parameters where to set the value
diff --git a/connectivity/inc/connectivity/filtermanager.hxx b/connectivity/inc/connectivity/filtermanager.hxx
index 3d720a1a21..a39e57ac35 100644
--- a/connectivity/inc/connectivity/filtermanager.hxx
+++ b/connectivity/inc/connectivity/filtermanager.hxx
@@ -34,7 +34,8 @@
#include <com/sun/star/sdb/XSQLQueryComposer.hpp>
#include <com/sun/star/sdbc/XConnection.hpp>
/** === end UNO includes === **/
-#include <rtl/ustring.hxx>
+
+#include <rtl/ustrbuf.hxx>
#include <vector>
#include "connectivity/dbtoolsdllapi.hxx"
@@ -112,10 +113,10 @@ namespace dbtools
/** appends one filter component to the statement in our composer
*/
- void appendFilterComponent( ::rtl::OUString& /* [inout] */ _rAppendTo, const ::rtl::OUString& _rComponent ) const;
+ void appendFilterComponent( ::rtl::OUStringBuffer& io_appendTo, const ::rtl::OUString& i_component ) const;
/// checks whether there is only one (or even no) non-empty filter component
- bool isThereAtMostOneComponent( ::rtl::OUString& _rOnlyComponent ) const;
+ bool isThereAtMostOneComponent( ::rtl::OUStringBuffer& o_singleComponent ) const;
/// returns the index of the first filter component which should be considered when building the composed filter
inline sal_Int32 getFirstApplicableFilterIndex() const
diff --git a/connectivity/inc/connectivity/sqlerror.hxx b/connectivity/inc/connectivity/sqlerror.hxx
index d360a32bea..afccfc9381 100644
--- a/connectivity/inc/connectivity/sqlerror.hxx
+++ b/connectivity/inc/connectivity/sqlerror.hxx
@@ -178,7 +178,7 @@ namespace connectivity
the ErrorCondition which hit you
@param _rxContext
- the context in which the error occured. This will be filled in as
+ the context in which the error occurred. This will be filled in as
<member scope="com::sun::star::uno">Exception::Context</member> member.
@param _rParamValue1
@@ -215,7 +215,7 @@ namespace connectivity
Note: You should prefer the version of <type>raiseException</type> which takes
an additional <type>Context</type> parameter, since this allows clients of your
- exception to examine where the error occured.
+ exception to examine where the error occurred.
@param _eCondition
the ErrorCondition which hit you
@@ -253,7 +253,7 @@ namespace connectivity
the ErrorCondition which hit you
@param _rxContext
- the context in which the error occured. This will be filled in as
+ the context in which the error occurred. This will be filled in as
<member scope="com::sun::star::uno">Exception::Context</member> member.
@param _rExceptionType
@@ -299,7 +299,7 @@ namespace connectivity
the ErrorCondition which hit you
@param _rxContext
- the context in which the error occured. This will be filled in as
+ the context in which the error occurred. This will be filled in as
<member scope="com::sun::star::uno">Exception::Context</member> member.
@param _rParamValue1
diff --git a/connectivity/inc/connectivity/sqlnode.hxx b/connectivity/inc/connectivity/sqlnode.hxx
index cc853d606e..ba9e029133 100644
--- a/connectivity/inc/connectivity/sqlnode.hxx
+++ b/connectivity/inc/connectivity/sqlnode.hxx
@@ -124,13 +124,16 @@ namespace connectivity
friend class OSQLParser;
OSQLParseNodes m_aChildren;
- OSQLParseNode* m_pParent; // pParent fuer Reuckverkettung im Baum
- ::rtl::OUString m_aNodeValue; // Token-Name oder leer bei Regeln oder ::rtl::OUString bei
- // ::rtl::OUString, INT, usw. -Werten
- SQLNodeType m_eNodeType; // s. o.
- sal_uInt32 m_nNodeID; // ::com::sun::star::chaos::Rule ID (bei IsRule()) oder Token ID (bei !IsRule())
- // ::com::sun::star::chaos::Rule IDs und Token IDs koennen nicht anhand des Wertes
- // unterschieden werden, dafuer ist IsRule() abzufragen!
+ OSQLParseNode* m_pParent; // pParent for reverse linkage in the tree
+ ::rtl::OUString m_aNodeValue; // token name, or empty in case of rules,
+ // or ::rtl::OUString in case of
+ // ::rtl::OUString, INT, etc.
+ SQLNodeType m_eNodeType; // see above
+ sal_uInt32 m_nNodeID; // ::com::sun::star::chaos::Rule ID (if IsRule())
+ // or Token ID (if !IsRule())
+ // ::com::sun::star::chaos::Rule IDs and Token IDs can't
+ // be distinguished by their values,
+ // IsRule has to be used for that!
public:
enum Rule
{
@@ -233,7 +236,7 @@ namespace connectivity
other_like_predicate_part_2,
between_predicate_part_2,
cast_spec,
- rule_count, // letzter_wert
+ rule_count, // last value
UNKNOWN_RULE // ID indicating that a node is no rule with a matching Rule-enum value (see getKnownRuleID)
};
@@ -254,22 +257,19 @@ namespace connectivity
SQLNodeType _eNodeType,
sal_uInt32 _nNodeID = 0);
- // Kopiert den entsprechenden ParseNode
+ // copies the respective ParseNode
OSQLParseNode(const OSQLParseNode& rParseNode);
OSQLParseNode& operator=(const OSQLParseNode& rParseNode);
sal_Bool operator==(OSQLParseNode& rParseNode) const;
- // Destruktor raeumt rekursiv den Baum ab
+ // destructor destructs the tree recursively
virtual ~OSQLParseNode();
- // Parent gibt den Zeiger auf den Parent zurueck
OSQLParseNode* getParent() const {return m_pParent;};
- // SetParent setzt den Parent-Zeiger eines ParseNodes
void setParent(OSQLParseNode* pParseNode) {m_pParent = pParseNode;};
- // ChildCount liefert die Anzahl der Kinder eines Knotens
sal_uInt32 count() const {return m_aChildren.size();};
inline OSQLParseNode* getChild(sal_uInt32 nPos) const;
@@ -304,7 +304,7 @@ namespace connectivity
too, to check whether they contain nested sub queries.
@param _pErrorHolder
- takes the error which occured while generating the statement, if any. Might be <NULL/>,
+ takes the error which occurred while generating the statement, if any. Might be <NULL/>,
in this case the error is not reported back, and can only be recognized by examing the
return value.
@@ -350,42 +350,37 @@ namespace connectivity
OSQLParseNode* getByRule(OSQLParseNode::Rule eRule) const;
#if OSL_DEBUG_LEVEL > 0
- // zeigt den ParseTree mit tabs und linefeeds
+ // shows the ParseTree with tabs and linefeeds
void showParseTree( ::rtl::OUString& rString ) const;
void showParseTree( ::rtl::OUStringBuffer& _inout_rBuf, sal_uInt32 nLevel ) const;
#endif
- // GetNodeType gibt den Knotentyp zurueck
SQLNodeType getNodeType() const {return m_eNodeType;};
- // RuleId liefert die RuleId der Regel des Knotens (nur bei IsRule())
+ // RuleId returns the RuleID of the node's rule (only if IsRule())
sal_uInt32 getRuleID() const {return m_nNodeID;}
/** returns the ID of the rule represented by the node
-
If the node does not represent a rule, UNKNOWN_RULE is returned
*/
Rule getKnownRuleID() const;
- // RuleId liefert die TokenId des Tokens des Knotens (nur bei ! IsRule())
+ // returns the TokenId of the node's token (only if !isRule())
sal_uInt32 getTokenID() const {return m_nNodeID;}
- // IsRule testet ob ein Node eine Regel (NonTerminal) ist
- // Achtung : Regeln koenne auch Blaetter sein, z.B. leere Listen
+ // IsRule tests whether a node is a rule (NonTerminal)
+ // ATTENTION: rules can be leaves, for example empty lists
sal_Bool isRule() const
{ return (m_eNodeType == SQL_NODE_RULE) || (m_eNodeType == SQL_NODE_LISTRULE)
|| (m_eNodeType == SQL_NODE_COMMALISTRULE);}
- // IsToken testet ob ein Node ein Token (Terminal) ist
- sal_Bool isToken() const {return !isRule();} // ein Token ist keine Regel
+ // IsToken tests whether a Node is a Token (Terminal but not a rule)
+ sal_Bool isToken() const {return !isRule();}
- // TokenValue liefert den NodeValue eines Tokens
const ::rtl::OUString& getTokenValue() const {return m_aNodeValue;}
- // SetTokenValue setzt den NodeValue
void setTokenValue(const ::rtl::OUString& rString) { if (isToken()) m_aNodeValue = rString;}
- // IsLeaf testet ob ein Node ein Blatt ist
sal_Bool isLeaf() const {return m_aChildren.empty();}
// negate only a searchcondition, any other rule could cause a gpf
@@ -415,7 +410,7 @@ namespace connectivity
::rtl::OUString &_rTable
,const ::com::sun::star::uno::Reference< ::com::sun::star::sdbc::XDatabaseMetaData >& _xMetaData);
- // susbtitute all occurences of :var or [name] into the dynamic parameter ?
+ // susbtitute all occurrences of :var or [name] into the dynamic parameter ?
// _pNode will be modified if parameters exists
static void substituteParameterNames(OSQLParseNode* _pNode);
@@ -424,7 +419,7 @@ namespace connectivity
static ::rtl::OUString getTableRange(const OSQLParseNode* _pTableRef);
protected:
- // ParseNodeToStr konkateniert alle Token (Blaetter) des ParseNodes
+ // ParseNodeToStr konkateniert alle Token (leaves) des ParseNodes
void parseNodeToStr(::rtl::OUString& rString,
const ::com::sun::star::uno::Reference< ::com::sun::star::sdbc::XConnection >& _rxConnection,
const ::com::sun::star::uno::Reference< ::com::sun::star::util::XNumberFormatter > & xFormatter,
diff --git a/connectivity/inc/connectivity/sqlparse.hxx b/connectivity/inc/connectivity/sqlparse.hxx
index d55c555ef5..531f1acbce 100644
--- a/connectivity/inc/connectivity/sqlparse.hxx
+++ b/connectivity/inc/connectivity/sqlparse.hxx
@@ -208,24 +208,23 @@ namespace connectivity
/// access to the SQLError instance owned by this parser
const SQLError& getErrorHelper() const;
- // TokenIDToStr: Token-Name zu einer Token-Nr.
+ // TokenIDToStr: token name belonging to a token number.
static ::rtl::OString TokenIDToStr(sal_uInt32 nTokenID, const IParseContext* pContext = NULL);
- // StrToTokenID: Token-Nr. zu einem Token-Namen.
+ // StrToTokenID: token number belonging to a token name.
// static sal_uInt32 StrToTokenID(const ::rtl::OString & rName);
- // RuleIDToStr gibt den zu einer RuleID gehoerenden ::rtl::OUString zurueck
- // (Leerstring, falls nicht gefunden)
+ // (empty string if not found)
static ::rtl::OUString RuleIDToStr(sal_uInt32 nRuleID);
- // StrToRuleID berechnet zu einem ::rtl::OUString die RuleID (d.h. ::com::sun::star::sdbcx::Index in yytname)
- // (0, falls nicht gefunden). Die Suche nach der ID aufgrund eines Strings ist
- // extrem ineffizient (sequentielle Suche nach ::rtl::OUString)!
+ // StrToRuleID calculates the RuleID for a ::rtl::OUString (that is, ::com::sun::star::sdbcx::Index in yytname)
+ // (0 if not found). The search for an ID based on a String is
+ // extremely inefficient (sequential search for ::rtl::OUString)!
static sal_uInt32 StrToRuleID(const ::rtl::OString & rValue);
static OSQLParseNode::Rule RuleIDToRule( sal_uInt32 _nRule );
- // RuleId mit enum, wesentlich effizienter
+ // RuleId with enum, far more efficient
static sal_uInt32 RuleID(OSQLParseNode::Rule eRule);
// compares the _sFunctionName with all known function names and return the DataType of the return value
static sal_Int32 getFunctionReturnType(const ::rtl::OUString& _sFunctionName, const IParseContext* pContext = NULL);
diff --git a/connectivity/inc/connectivity/virtualdbtools.hxx b/connectivity/inc/connectivity/virtualdbtools.hxx
index 1760a9c835..9bbb57e433 100644
--- a/connectivity/inc/connectivity/virtualdbtools.hxx
+++ b/connectivity/inc/connectivity/virtualdbtools.hxx
@@ -257,17 +257,16 @@ namespace connectivity
virtual double getValue(
const ::com::sun::star::uno::Reference< ::com::sun::star::sdb::XColumn>& _rxVariant,
- const ::com::sun::star::util::Date& rNullDate,
- sal_Int16 nKeyType) const = 0;
+ const ::com::sun::star::util::Date& rNullDate ) const = 0;
- virtual ::rtl::OUString getValue(
+ virtual ::rtl::OUString getFormattedValue(
const ::com::sun::star::uno::Reference< ::com::sun::star::sdb::XColumn >& _rxColumn,
const ::com::sun::star::uno::Reference< ::com::sun::star::util::XNumberFormatter >& _rxFormatter,
const ::com::sun::star::util::Date& _rNullDate,
sal_Int32 _nKey,
sal_Int16 _nKeyType) const = 0;
- virtual ::rtl::OUString getValue(
+ virtual ::rtl::OUString getFormattedValue(
const ::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet>& _rxColumn,
const ::com::sun::star::uno::Reference< ::com::sun::star::util::XNumberFormatter>& _rxFormatter,
const ::com::sun::star::lang::Locale& _rLocale,
diff --git a/connectivity/inc/makefile.mk b/connectivity/inc/makefile.mk
index 51a3f225b3..51a3f225b3 100644..100755
--- a/connectivity/inc/makefile.mk
+++ b/connectivity/inc/makefile.mk
diff --git a/connectivity/inc/connectivity/sqliterator.hxx b/connectivity/inc/connectivity/sqliterator.hxx
index 0e61f34bc7..0593aa11e1 100644
--- a/connectivity/inc/connectivity/sqliterator.hxx
+++ b/connectivity/inc/connectivity/sqliterator.hxx
@@ -67,10 +67,10 @@ namespace connectivity
{
private:
::com::sun::star::sdbc::SQLException m_aErrors; // conatins the error while iterating through the statement
- const OSQLParseNode* m_pParseTree; // aktueller ParseTree
+ const OSQLParseNode* m_pParseTree; // current ParseTree
const OSQLParser& m_rParser; // if set used for general error messages from the context
- OSQLStatementType m_eStatementType; // Art des Statements
- ::rtl::Reference<OSQLColumns> m_aSelectColumns; // alle Spalten aus dem Select-Clause
+ OSQLStatementType m_eStatementType;
+ ::rtl::Reference<OSQLColumns> m_aSelectColumns; // all columns from the Select clause
::rtl::Reference<OSQLColumns> m_aParameters; // all parameters
::rtl::Reference<OSQLColumns> m_aGroupColumns; // the group by columns
::rtl::Reference<OSQLColumns> m_aOrderColumns; // the order by columns
@@ -79,7 +79,7 @@ namespace connectivity
::std::auto_ptr< OSQLParseTreeIteratorImpl > m_pImpl;
void traverseParameter(const OSQLParseNode* _pParseNode,const OSQLParseNode* _pColumnRef,const ::rtl::OUString& _aColumnName,const ::rtl::OUString& _aTableRange, const ::rtl::OUString& _rColumnAlias);
- // F"ugt eine Tabelle in die Map ein
+ // inserts a table into the map
void traverseOneTableName( OSQLTables& _rTables,const OSQLParseNode * pTableName, const ::rtl::OUString & rTableRange );
void traverseORCriteria(OSQLParseNode * pSearchCondition);
void traverseANDCriteria(OSQLParseNode * pSearchCondition);
@@ -124,11 +124,10 @@ namespace connectivity
protected:
void setSelectColumnName(::rtl::Reference<OSQLColumns>& _rColumns,const ::rtl::OUString & rColumnName,const ::rtl::OUString & rColumnAlias, const ::rtl::OUString & rTableRange,sal_Bool bFkt=sal_False,sal_Int32 _nType = com::sun::star::sdbc::DataType::VARCHAR,sal_Bool bAggFkt=sal_False);
void appendColumns(::rtl::Reference<OSQLColumns>& _rColumns,const ::rtl::OUString& _rTableAlias,const OSQLTable& _rTable);
- // Weitere Member-Variable, die in den "set"-Funktionen zur
- // Verfuegung stehen sollen, koennen in der abgeleiteten Klasse
- // definiert werden und z. B. in deren Konstruktor initialisiert
- // bzw. nach Benutzung der "traverse"-Routinen mit Hilfe weiterer
- // Funktionen abgefragt werden.
+ // Other member variables that should be available in the "set" functions
+ // can be defined in the derived class. They can be initialized
+ // in its constructor and, after the "traverse" routines have been used,
+ // they can be queried using other functions.
private:
@@ -154,13 +153,13 @@ namespace connectivity
void dispose();
bool isCaseSensitive() const;
- // Der zu analysierende/zu traversierende Parse Tree:
- // bei "Ubergabe von NULL wird der aktuelle Parsetree gel"oscht und der Fehlerstatus gecleared
+ // The parse tree to be analysed/traversed:
+ // If NULL is passed, the current parse tree will be deleted and the error status cleared.
void setParseTree(const OSQLParseNode * pNewParseTree);
// void setParser(const OSQLParser* _pParser) { m_pParser = _pParser; }
const OSQLParseNode * getParseTree() const { return m_pParseTree; };
- // Teilbaueme bei einem select statement
+ // subtrees in case of a select statement
const OSQLParseNode* getWhereTree() const;
const OSQLParseNode* getOrderTree() const;
const OSQLParseNode* getGroupByTree() const;
@@ -171,14 +170,14 @@ namespace connectivity
const OSQLParseNode* getSimpleGroupByTree() const;
const OSQLParseNode* getSimpleHavingTree() const;
/** returns the errors which occured during parsing.
The returned object contains a chain (via SQLException::NextException) of SQLExceptions.
*/
inline const ::com::sun::star::sdbc::SQLException& getErrors() const { return m_aErrors; }
inline bool hasErrors() const { return m_aErrors.Message.getLength() > 0; }
- // Statement-Typ (wird bereits in setParseTree gesetzt):
+ // statement type (already set in setParseTree):
OSQLStatementType getStatementType() const { return m_eStatementType; }
/** traverses the complete statement tree, and fills all our data with
@@ -212,7 +211,7 @@ namespace connectivity
*/
void traverseSome( sal_uInt32 _nIncludeMask );
- // Die TableRangeMap enth"alt alle Tabellen unter dem zugeh"origen Rangenamen der zuerst gefunden wird
+ // The TableRangeMap contains all tables associated with the range name found first.
const OSQLTables& getTables() const;
::rtl::Reference<OSQLColumns> getSelectColumns() const { return m_aSelectColumns;}
@@ -274,8 +273,7 @@ namespace connectivity
::rtl::OUString &_rColumnName,
::rtl::OUString& _rTableRange);
- // Ermittelt fuer eine Funktion, Spalten den zugehoeren TableRange,
- // wenn nicht eindeutig, dann leer
+ // empty if ambiguous
sal_Bool getColumnTableRange(const OSQLParseNode* pNode, ::rtl::OUString &rTableRange) const;
// return true when the tableNode is a rule like catalog_name, schema_name or table_name
@@ -338,12 +336,12 @@ namespace connectivity
/** appends an SQLException corresponding to the given error code to our error collection
@param _eError
- the code of the error which occured
+ the code of the error which occurred
@param _pReplaceToken1
- if not <NULL/>, the first occurance of '#' in the error message will be replaced
+ if not <NULL/>, the first occurrence of '#' in the error message will be replaced
with the given token
@param _pReplaceToken2
- if not <NULL/>, and if _rReplaceToken1 is not <NULL/>, the second occurance of '#'
+ if not <NULL/>, and if _rReplaceToken1 is not <NULL/>, the second occurrence of '#'
in the error message will be replaced with _rReplaceToken2
*/
void impl_appendError( IParseContext::ErrorCode _eError,
@@ -171,14 +170,14 @@ namespace connectivity
const OSQLParseNode* getSimpleGroupByTree() const;
const OSQLParseNode* getSimpleHavingTree() const;
- /** returns the errors which occured during parsing.
+ /** returns the errors which occurred during parsing.
The returned object contains a chain (via SQLException::NextException) of SQLExceptions.
*/